@@ -12,7 +12,7 @@ maintaining the widget state and invoking callbacks, all aspects
 of the widgets appearance lies at Themes.
 """
 
-__version__ = "0.1.5"
+__version__ = "0.1.6"
 
 __author__ = "Guilherme Polo <ggpolo@gmail.com>"
 
@@ -321,18 +321,12 @@ def _val_or_dict(options, func, *args):
     return _dict_from_tcltuple(res)
 
 def _convert_stringval(value):
-    """Converts a value, that may possibly represents a sequence,
-    hopefully, to a more appropriate Python object."""
+    """Converts a value to, hopefully, a more appropriate Python object."""
+    value = unicode(value)
     try:
         value = int(value)
     except (ValueError, TypeError):
-        if ' ' in value:
-            value = map(str, value)
-            try:
-                value = map(int, value)
-            except ValueError:
-                # this value needs no conversion apparently
-                pass
+        pass
 
     return value
 
@@ -340,19 +334,14 @@ def tclobjs_to_py(adict):
     """Returns adict with its values converted from Tcl objects to Python
     objects."""
     for opt, val in adict.iteritems():
-        if isinstance(val, basestring):
-            val = _convert_stringval(val)
-
-        elif val and hasattr(val, '__len__'):
+        if val and hasattr(val, '__len__') and not isinstance(val, basestring):
             if getattr(val[0], 'typename', None) == 'StateSpec':
                 val = _list_from_statespec(val)
             else:
-                # converts a sequence that possibly has Tcl objects, or not,
-                # to a better representation
-                val = map(_convert_stringval, map(str, val))
+                val = map(_convert_stringval, val)
 
-        elif hasattr(val, 'typename'): # some other Tcl object
-            val = str(val)
+        elif hasattr(val, 'typename'): # some other (single) Tcl object
+            val = _convert_stringval(val)
 
         adict[opt] = val
 
